svn commit: r362419 - head/sys/cam

Warner Losh imp at FreeBSD.org
Sat Jun 20 04:07:25 UTC 2020


Author: imp
Date: Sat Jun 20 04:07:23 2020
New Revision: 362419
URL: https://svnweb.freebsd.org/changeset/base/362419

Log:
  Use the more descriptive src_ccb and dst_ccb for the two ccbs being merged.
  
  MFC after: 1 week

Modified:
  head/sys/cam/cam_xpt.c
  head/sys/cam/cam_xpt.h

Modified: head/sys/cam/cam_xpt.c
==============================================================================
--- head/sys/cam/cam_xpt.h	Fri Jun 19 23:32:40 2020	(r362418)
+++ head/sys/cam/cam_xpt.h	Sat Jun 20 04:07:23 2020	(r362419)
@@ -86,8 +86,8 @@ void			xpt_setup_ccb_flags(struct ccb_hdr *ccb_h,
 void			xpt_setup_ccb(struct ccb_hdr *ccb_h,
 				      struct cam_path *path,
 				      u_int32_t priority);
-void			xpt_merge_ccb(union ccb *master_ccb,
-				      union ccb *slave_ccb);
+void			xpt_merge_ccb(union ccb *dst_ccb,
+				      union ccb *src_ccb);
 cam_status		xpt_create_path(struct cam_path **new_path_ptr,
 					struct cam_periph *perph,
 					path_id_t path_id,


More information about the svn-src-all mailing list
--- head/sys/cam/cam_xpt.c	Fri Jun 19 23:32:40 2020	(r362418)
+++ head/sys/cam/cam_xpt.c	Sat Jun 20 04:07:23 2020	(r362419)
@@ -3526,22 +3526,22 @@ xpt_run_devq(struct cam_devq *devq)
 }
 
 /*
  * This function merges stuff from the slave ccb into the master ccb, while
  * keeping important fields in the master ccb constant.
  */
 void
-xpt_merge_ccb(union ccb *master_ccb, union ccb *slave_ccb)
+xpt_merge_ccb(union ccb *dst_ccb, union ccb *src_ccb)
 {
 
 	/*
 	 * Pull fields that are valid for peripheral drivers to set
 	 * into the master CCB along with the CCB "payload".
 	 */
-	master_ccb->ccb_h.retry_count = slave_ccb->ccb_h.retry_count;
-	master_ccb->ccb_h.func_code = slave_ccb->ccb_h.func_code;
-	master_ccb->ccb_h.timeout = slave_ccb->ccb_h.timeout;
-	master_ccb->ccb_h.flags = slave_ccb->ccb_h.flags;
-	bcopy(&(&slave_ccb->ccb_h)[1], &(&master_ccb->ccb_h)[1],
+	dst_ccb->ccb_h.retry_count = src_ccb->ccb_h.retry_count;
+	dst_ccb->ccb_h.func_code = src_ccb->ccb_h.func_code;
+	dst_ccb->ccb_h.timeout = src_ccb->ccb_h.timeout;
+	dst_ccb->ccb_h.flags = src_ccb->ccb_h.flags;
+	bcopy(&(&src_ccb->ccb_h)[1], &(&dst_ccb->ccb_h)[1],
 	      sizeof(union ccb) - sizeof(struct ccb_hdr));
 }
 
@@ -3526,22 +3526,22 @@ xpt_run_devq(struct cam_devq *devq)
 
 /*
- * This function merges stuff from the slave ccb into the master ccb, while
- * keeping important fields in the master ccb constant.
+ * This function merges stuff from the src ccb into the dst ccb, while keeping
+ * important fields in the dst ccb constant.
  */
 void
@@ -3526,22 +3526,22 @@ xpt_run_devq(struct cam_devq *devq)
 	/*
 	 * Pull fields that are valid for peripheral drivers to set
-	 * into the master CCB along with the CCB "payload".
+	 * into the dst CCB along with the CCB "payload".
 	 */

Modified: head/sys/cam/cam_xpt.h
==============================================================================